@@ -1,5 +1,5 @@
 from tailwindcss.templatetags.tailwindcss import tailwind
 
 
-def refresh_tailwindcss():
+def refresh_tailwindcss(sender, **kwargs):
     tailwind.refresh()
\ No newline at end of file
