@@ -1,9 +1,9 @@
 from django.test import SimpleTestCase
 
-from tailwindcss.templatetags.tailwindcss import init_tailwindcss_text
+from tailwindcss.templatetags.tailwindcss import tailwind
 
 
 class TailwindCSSTestCase(SimpleTestCase):
     def test_init_tailwindcss_text(self):
-        css_text = init_tailwindcss_text()
+        css_text = tailwind.css
         self.assertIsNotNone(css_text)
\ No newline at end of file
